function one_disk, x, y, p
;+
; NAME:  one_disk
;
;
;
; PURPOSE:  Generate a single edge-on galaxy image using a sech^2
; vertical profile and exponential radial profile
;
;
;
; CATEGORY:
;
;
;
; CALLING SEQUENCE: blah=one_disk(x,y,p)
;
;
;
; INPUTS:
;       x:  2-d array with the x coordinate for each pixel (use makex for
; quick and easy creation of x and y).  Note x and y should be even
; (ie 100x100, not 101x101).  If they have an odd number of elements
; in a dimension, IDL will try to evaluate the Bessel function  at 0,
; and that sucks. 
;        y:  2-d array with the y coordinate for each pixel 
;        p: 3 element array. 
;        p(0)=central surface brightness (this is edge-on, check out van der
; Kruit and Searle 1980 I for how it all relates to central luminosity
; density and/or face-on central surface brightness)
;        p(1)=exponential scale length
;        p(2)=vertical scale parameter z_0
;
;
; OPTIONAL INPUTS:
;
;
;
; KEYWORD PARAMETERS:
;
;
;
; OUTPUTS:
;
;
;
; OPTIONAL OUTPUTS:
;
;
;
; COMMON BLOCKS:
;
;
;
; SIDE EFFECTS:
;
;
;
; RESTRICTIONS:
;
;
;
; PROCEDURE:
;
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
;
;01/07--added compatibility for x=0
;-



;p is the form [central luminosity, scale length, scale height]
;p=abs(p)

x=abs(x)
y=abs(y)
result=p(0)*( cosh(y/(abs(p(2)))))^(-2.)*(x/p(1))*beselk(x/p(1),1)
;make beselk function equal to 1 at zero
if max(where(x eq 0)) ne -1 then begin
  zos=where(x eq 0)
  result(zos)=p(0)*( cosh(y(zos)/(abs(p(2)))))^(-2.)
endif

return, result
end

