function two_disk, x, y, p, mask=mask, splitdisk=splitdisk	
;+
; NAME:  two_disk
;
;
;
; PURPOSE:  generate a two-component model edge-on galaxy.  Each
; component has an exponential radial profile and a sech^2 vertical
; profile.  Designed to be used in the linear regime (i.e., fits
; distribution of counts or flux, not surface brightness in mag/arcsec^2)
;
;
;
; CATEGORY:  
;
;
;
; CALLING SEQUENCE:  blah=two_disk(x,y,p)
;
;
;
; INPUTS: 
;        x:  2-d array with the x coordinate for each pixel (use makex for
; quick and easy creation of x and y).  Note x and y should be even
; (ie 100x100, not 101x101).  If they have an odd number of elements
; in a dimension, IDL will try to evaluate the Bessel function  at 0,
; and that sucks. 
;        y:  2-d array with the y coordinate for each pixel 
;        p:  9-elements array containing all the parameters to make
; the model galaxy:
;           p(0)=disk 1 central surface brightness  (this is edge-on,
; check out van der 
; Kruit and Searle 1980 I for how it all relates to central luminosity
; density and/or face-on central surface brightness)
;           p(1)=disk 1 exponential scale length
;           p(2)=disk 1 vertical scale parameter z_0
;           p(3)=disk 2 central surface brightness
;           p(4)=disk 2 exponential scale length
;           p(5)=disk 2 vertical scale parameter z_0
;           p(6)=integer x shift 
;           p(7)=integer y shift
;           p(8)=rotation angle; the same shift and rotation is
; applied to each galaxy
;
; OPTIONAL INPUTS:
;           mask:  if you want to output masked, just give it a mask.
;
;
; KEYWORD PARAMETERS:
;           \splitdisk:  splits the output into separate disks.
;           
;
; OUTPUTS:
;           a model galaxy.
;
;
; OPTIONAL OUTPUTS:
;
;
;
; COMMON BLOCKS:
;
;
;
; SIDE EFFECTS:
;
;
;
; RESTRICTIONS:
;
;
;
; PROCEDURE:
;
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
;01/07:  added compatibility for x=0
;
;-



;p should be [d1 lum, d1 length, d1 height, d2 lum, d2 legth, d2 height, shift x, shift y, rot angle]
x=abs(x)
y=abs(y)
p(0:5)=abs(p(0:5))
N=1

radial1=(x/p(1))*beselk(x/p(1),1)
radial2=(x/p(4))*beselk(x/p(4),1)

if max(where(x eq 0)) ne -1 then begin
  ack=where(x eq 0)
  radial1(ack)=1
  radial2(ack)=1
endif


disk1=(  cosh(     (N*y)/(abs(p(2))) )      )^(-2./N) 
disk2=(  cosh(     (N*y)/(abs(p(5))) )      )^(-2./N)
result=abs(p(0))*radial1*disk1+abs(p(3))*disk2*radial2

if keyword_set(mask) then begin
	result=result*mask
endif
result=rot(result,p(8), /interp)	;and rotate
result=shift(result, p(6),p(7) )	;shift



if keyword_set(splitdisk) then begin
       	res1=disk1*radial1*abs(p(0))
        res2=abs(p(3))*disk2*radial2
        blah=size(x)
        result=dblarr(blah(1),blah(2), 2)
	result(*,*,0)=rot( result(*,*,0), p(8), /interp )
	result(*,*,1)=rot(result(*,*,1), p(8) , /interp)
        result(*,*,0)=shift( res1 , p(6),p(7) )
	result(*,*,1)=shift(res2, p(6),p(7) )
endif

return, result
end
